[![@wq/model][logo]][docs]

**@wq/model** is a [wq.app] module providing a simple API for working with lists, or collections of similar objects.  It integrates with [@wq/app] to load the [ORM configuration], and uses [@wq/store] to retrieve the underlying JSON data from e.g. a [wq.db REST API][wq.db].  @wq/model is based on [Redux-ORM] and provides similar querying capabilities, while also supporting asyncronous APIs for paginating through data from the server.

### [Documentation][docs]

[**Installation**][installation]
&bull;
[**API**][api]
&bull;
[Configuration][configuration]
&bull;
[Methods][methods]

[logo]: https://wq.io/images/@wq/model.svg
[docs]: https://wq.io/@wq/model
[installation]: https://wq.io/@wq/model#installation
[api]: https://wq.io/@wq/model#api
[configuration]: https://wq.io/@wq/model#configuration
[methods]: https://wq.io/@wq/model#methods

[wq.app]: https://wq.io/wq.app/
[wq.db]: https://wq.io/wq.db/
[@wq/app]: https://wq.io/@wq/app
[@wq/store]: https://wq.io/@wq/store

[Redux-ORM]: https://github.com/redux-orm/redux-orm
